import customtkinter as ctk
from tkinter import messagebox
from utils.api_requests import register_api  # Import the API function


def register_frame(parent, switch_func, API_URL):
    # Create a full-window container with a light gray background
    container = ctk.CTkFrame(parent, fg_color="#F3F4F6")
    container.pack(expand=True, fill="both")
    
    # Center the register panel (the white card) in the middle of the container.
    # Width and height are set to ensure a consistent size.
    register_panel = ctk.CTkFrame(container, fg_color="white", corner_radius=20, width=400, height=500)
    register_panel.place(relx=0.5, rely=0.5, anchor="center")

    def register():
        username = entry_username.get()
        email = entry_email.get()
        phone_number = entry_phone.get()
        password = entry_password.get()
        confirm_password = entry_confirm_password.get()

        if not username or not email or not phone_number or not password or not confirm_password:
            messagebox.showwarning("Input Error", "All fields are required!")
            return

        if password != confirm_password:
            messagebox.showerror("Password Error", "Passwords do not match!")
            return

        # Call the API function from register_api.py
        status_code, response_data = register_api(
            username, email, phone_number, password, API_URL
        )

        if status_code == 200:
            messagebox.showinfo("Registration Successful", f"Welcome, {username}!")
            switch_func("login")
        else:
            messagebox.showerror("Registration Failed", response_data.get("detail", "Unknown error"))

    # Title for the registration form
    ctk.CTkLabel(
        register_panel,
        text="Create Account",
        font=ctk.CTkFont("Helvetica", size=26, weight="bold"),
        text_color="#111827"
    ).pack(pady=(20, 10))

    # Username Entry
    entry_username = ctk.CTkEntry(
        register_panel, placeholder_text="Username", height=40, corner_radius=10, width=250
    )
    entry_username.pack(pady=10, padx=20, fill="x")

    # Email Entry
    entry_email = ctk.CTkEntry(
        register_panel, placeholder_text="Email", height=40, corner_radius=10, width=250
    )
    entry_email.pack(pady=10, padx=20, fill="x")

    # Phone Number Entry
    entry_phone = ctk.CTkEntry(
        register_panel, placeholder_text="Phone Number", height=40, corner_radius=10, width=250
    )
    entry_phone.pack(pady=10, padx=20, fill="x")

    # Password Entry
    entry_password = ctk.CTkEntry(
        register_panel, placeholder_text="Password", show="*", height=40, corner_radius=10, width=250
    )
    entry_password.pack(pady=10, padx=20, fill="x")

    # Confirm Password Entry
    entry_confirm_password = ctk.CTkEntry(
        register_panel, placeholder_text="Confirm Password", show="*", height=40, corner_radius=10, width=250
    )
    entry_confirm_password.pack(pady=10, padx=20, fill="x")

    # Register Button
    ctk.CTkButton(
        register_panel,
        text="Register",
        command=register,
        corner_radius=10,
        height=45,
        font=("Helvetica", 14),
        fg_color="#2563EB",
        hover_color="#1E40AF"
    ).pack(pady=20, padx=20, fill="x")

    # Link to Login Page
    ctk.CTkButton(
        register_panel,
        text="Already have an account? Login",
        command=lambda: switch_func("login"),
        fg_color="transparent",
        hover_color="#E5E7EB",
        text_color="#2563EB"
    ).pack(pady=(5, 20))

    return container
